@@ -81,6 +81,9 @@ class HardsubSignKgf(HardsubMask):
     """
     Hardsub scenefiltering helper using kgf.hardsubmask_fades.
 
+    Dependencies:
+    * kagefunc
+
     :param highpass: Highpass filter for hardsub detection (16-bit, Default: 5000)
     :param expand:   ``kgf.hardsubmask_fades`` expand parameter (Default: 8)
     """
@@ -131,6 +134,9 @@ class HardsubLine(HardsubMask):
     """
     Hardsub scenefiltering helper using kgf.hardsubmask.
 
+    Dependencies:
+    * kagefunc
+
     :param expand: ``kgf.hardsubmask`` expand parameter (Default: clip.width // 200)
     """
     expand: Optional[int]
