@@ -32,7 +32,6 @@ def quick_resample(clip: vs.VideoNode,
     return depth(filtered, clip.format.bits_per_sample)
 
 
-# TODO: Merge pick_repair and pick_removegrain?
 def pick_repair(clip: vs.VideoNode) -> Callable[..., vs.VideoNode]:
     """
     Returns rgvs.Repair if the clip is 16 bit or lower, else rgsf.Repair.
@@ -54,7 +53,8 @@ def pick_removegrain(clip: vs.VideoNode) -> Callable[..., vs.VideoNode]:
     Returns rgvs.RemoveGrain if the clip is 16 bit or lower, else rgsf.RemoveGrain.
     This is done because rgvs doesn't work with float, but rgsf does for whatever reason.
 
-    Dependencies: rgsf
+    Dependencies:
+    * RGSF
 
     :param clip: Input clip
 
